import { Meta } from "@storybook/addon-docs";

<Meta title="Introduction/Developer Guides/Storybook 8 Migration Guide" />

# Storybook 8 Migration Guide

## Best Practice Stories in Storybook 8

With the upgrade to Storybook version 8, a new approach for writing stories is needed. In this guide, we want to paint a clear picture how the stories should be structured from now on. Please see the few example stories for reference.

## Basic structure

As before, we want to separate the stories like this:

-   Components
-   Shared Templates / Partials (if necessary)
-   MyTrumpf
-   Website
-   E-Shop

## Before migrating stories

Please make sure to check the story before you migrate it.

-   Is it still relevant / used?
    -   If not, please remove it / don't migrate it
-   Is the design still up-to-date?
    -   Please get in touch with the design team or your PO if in doubt
    -   Adapt the template accordingly while you migrate it
-   Are there deprecated utility or gridle classes used?
    -   Please update the classes when necessary and clean up the code
-   Figma Verlinkung

## Migrating stories

1. Checkout into the feature/storybook-7-migration branch
2. Change into the packages/docs directory
    - Keep in mind to use **node v20** in this directory

### Migrating component stories

If you want to migrate a component story, we created a script to give you an easy start!
Please enter the component name **without** the `ux-iws-` prefix. This will be added automatically.

```javascript
npm run generate-story -- componentname
```

The script will create a folder with the component name inside stories/components. In this folder, you will find a .stories.js file and a .mdx file with some basic setup. This is meant as an orientation to get an idea about the basic setup. Please adapt the default content according to the component you're migrating.

### Migrating template stories

If you want to migrate a default template story for website, mytrumpf or shop, you can use this script
Please enter the story path and name like this

```javascript
npm run generate-story-default -- pathname storyname
```

### Overview of deprecated components that have not been migrated

-   ux-iws-status-label

### Todos

-   Teaser Counter Grid View Stories -> move to a website story
-   Teaser Icon Grid View Stories -> not migrated within components. Should be part of a website story
-   Teaser Image Grid View Stories -> not migrated within components. Should be part of a website story
-   Teaser Product Tile Grid View Stories -> not migrated within components. Should be part of a website story
-   Teaser Sidebar Icon Sidebar View Stories -> not migrated within components. Should be part of a website story
-   Teaser Video Search Grid View Stories -> not migrated within components. Should be part of a website story
-   Tile Variants
